import z from "zod"

export const PlantSchema = z.object({
    id: z.number(),
    name: z.string(),
    latinName: z.string().nullable(),
    description: z.string().nullable(),
    origin: z.string().nullable(),
    growingTips: z.string().nullable(),
    plantWeekStart: z.number().int().positive().nullable(),
    plantWeekEnd: z.number().int().positive().nullable(),
    harvestWeekStart: z.number().int().positive().nullable(),
    harvestWeekEnd: z.number().int().positive().nullable(),
    groundType: z.enum(["HEAVY", "MEDIUM", "LIGHT"]).transform(s => translateGroundType(s)).nullable(),
    waterDemand: z.enum(["DRY","WET","VERY_WET"]).transform(s=>translateWaterDemand(s)).nullable(),
    lightingDemand: z.enum(["LOW","MEDIUM","HIGH"]).transform(s=>translateLightingDemand(s)).nullable(),
    nutrientDemand: z.enum(["LOW","MEDIUM","HIGH"]).transform(s=>translateNutrientDemand(s)).nullable(),
    imageUrl: z.string().optional()
  });
  
  export type PlantNew = z.infer<typeof PlantSchema>;

  function translateLightingDemand(key: "LOW"|"MEDIUM"|"HIGH"){
    const map = {
        LOW: "Niedrig",
        MEDIUM: "Mittel",
        HIGH: "Hoch"
    } 
    return map[key];
  }

  function translateGroundType(key: "HEAVY" | "MEDIUM" | "LIGHT") {
    const map = {
        HEAVY: "Schwer",
        MEDIUM: "Mittel",
        LIGHT: "Leicht"
    } 
    return map[key];
  }

  function translateWaterDemand(key: "DRY"|"WET"|"VERY_WET"){
    const map = {
        DRY: "Trocken",
        WET: "Feucht",
        VERY_WET: "Sehr feucht"
    } 
    return map[key];
  }

  function translateNutrientDemand(key: "LOW"|"MEDIUM"|"HIGH"){
    const map = {
        LOW: "Nierig",
        MEDIUM: "Mittel",
        HIGH: "Hoch"
    } 
    return map[key];
  }
  

